@@ -51,13 +51,13 @@ func readMessage(messageFilePath string) (string, error) {
 	// Check that message file is existing.
 	_, err = os.Stat(messageFilePath)
 	if err != nil {
-		return output, fmt.Errorf("readMessage: %w", err)
+		return output, fmt.Errorf("read message: %w", err)
 	}
 
 	// Open message file.
 	file, err := os.Open(messageFilePath)
 	if err != nil {
-		return output, fmt.Errorf("readMessage: %w", err)
+		return output, fmt.Errorf("read message: %w", err)
 	}
 	defer file.Close()
 	scanner := bufio.NewScanner(file)
@@ -72,7 +72,7 @@ func readMessage(messageFilePath string) (string, error) {
 
 	if err = scanner.Err(); err != nil {
 		if err != io.EOF {
-			return "", fmt.Errorf("readMessage: %w", err)
+			return "", fmt.Errorf("read message: %w", err)
 		}
 	}
 
@@ -97,6 +97,8 @@ func main() {
 		failure error
 	)
 
+	log.SetFlags(0)
+	log.SetOutput(new(prettyLogger))
 	// Define command line flags.
 	flagHelp := getopt.BoolLong("help", 0, "Show help.")
 	flagHTTPUpload := getopt.ListLong("http-upload", 'h', "Send a file via http-upload. Can be invoked several times to upload multiple files.")
@@ -446,7 +448,7 @@ func main() {
 			re.OxKeyRing, err = oxGetPublicKeyRing(client, iqc, r)
 			if err != nil {
 				re.OxKeyRing = nil
-				fmt.Printf("Ox: error fetching key for %s: %v\n", r, err)
+				fmt.Printf("ox: error fetching key for %s: %v\n", r, err)
 				failure = err
 			}
 		}
@@ -626,7 +628,7 @@ func main() {
 					oxMessage, err := oxEncrypt(client, oxPrivKey,
 						recipient.Jid, *recipient.OxKeyRing, message, *flagSubject)
 					if err != nil {
-						fmt.Printf("Ox: couldn't encrypt to %s: %v\n",
+						fmt.Printf("ox: couldn't encrypt to %s: %v\n",
 							recipient.Jid, err)
 						failure = err
 						continue
@@ -771,7 +773,7 @@ func main() {
 				oxMessage, err := oxEncrypt(client, oxPrivKey,
 					recipient.Jid, *recipient.OxKeyRing, message, *flagSubject)
 				if err != nil {
-					fmt.Printf("Ox: couldn't encrypt to %s: %v\n",
+					fmt.Printf("ox: couldn't encrypt to %s: %v\n",
 						recipient.Jid, err)
 					failure = err
 					continue
